@@ -46,27 +46,19 @@ class PtCreater(object):
             entry_table[36 * entry_cnt + 0] = bflb_utils.int_to_2bytearray_l(entry_type)[0]
             if "activeindex" in item:
                 entry_activeindex = item["activeindex"]
-                entry_table[36 * entry_cnt +
-                            2] = bflb_utils.int_to_2bytearray_l(entry_activeindex)[0]
+                entry_table[36 * entry_cnt + 2] = bflb_utils.int_to_2bytearray_l(entry_activeindex)[0]
             if len(entry_name) >= 8:
                 bflb_utils.printf("%s entry name is too long!" % entry_name)
                 return False
-            entry_table[36 * entry_cnt + 3:36 * entry_cnt + 3 +
-                        len(entry_name)] = bytearray(entry_name, "utf-8") + bytearray(0) 
-            entry_table[36 * entry_cnt + 12:36 * entry_cnt +
-                        16] = bflb_utils.int_to_4bytearray_l(entry_addr0)
-            entry_table[36 * entry_cnt + 16:36 * entry_cnt +
-                        20] = bflb_utils.int_to_4bytearray_l(entry_addr1)
-            entry_table[36 * entry_cnt + 20:36 * entry_cnt +
-                        24] = bflb_utils.int_to_4bytearray_l(entry_maxlen0)
-            entry_table[36 * entry_cnt + 24:36 * entry_cnt +
-                        28] = bflb_utils.int_to_4bytearray_l(entry_maxlen1)
-            entry_table[36 * entry_cnt + 28:36 * entry_cnt +
-                        32] = bflb_utils.int_to_4bytearray_l(entry_len)
+            entry_table[36 * entry_cnt + 3:36 * entry_cnt + 3 + len(entry_name)] = bytearray(entry_name, "utf-8") + bytearray(0) 
+            entry_table[36 * entry_cnt + 12:36 * entry_cnt + 16] = bflb_utils.int_to_4bytearray_l(entry_addr0)
+            entry_table[36 * entry_cnt + 16:36 * entry_cnt + 20] = bflb_utils.int_to_4bytearray_l(entry_addr1)
+            entry_table[36 * entry_cnt + 20:36 * entry_cnt + 24] = bflb_utils.int_to_4bytearray_l(entry_maxlen0)
+            entry_table[36 * entry_cnt + 24:36 * entry_cnt + 28] = bflb_utils.int_to_4bytearray_l(entry_maxlen1)
+            entry_table[36 * entry_cnt + 28:36 * entry_cnt + 32] = bflb_utils.int_to_4bytearray_l(entry_len)
             if "age" in item:
                 entry_age = item["age"]
-                entry_table[36 * entry_cnt + 32:36 * entry_cnt +
-                            36] = bflb_utils.int_to_4bytearray_l(entry_age)
+                entry_table[36 * entry_cnt + 32:36 * entry_cnt + 36] = bflb_utils.int_to_4bytearray_l(entry_age)
             entry_cnt += 1
         # partition table header
         # 0x54504642
@@ -77,8 +69,7 @@ class PtCreater(object):
         pt_table[3] = 0x54
         pt_table[6:8] = bflb_utils.int_to_2bytearray_l(int(entry_cnt))
         pt_table[12:16] = bflb_utils.get_crc32_bytearray(pt_table[0:12])
-        entry_table[36 * entry_cnt:36 * entry_cnt + 4] = bflb_utils.get_crc32_bytearray(
-            entry_table[0:36 * entry_cnt])
+        entry_table[36 * entry_cnt:36 * entry_cnt + 4] = bflb_utils.get_crc32_bytearray(entry_table[0:36 * entry_cnt])
         data = pt_table + entry_table[0:36 * entry_cnt + 4]
         fp = open(file, 'wb+')
         fp.write(data)
@@ -105,72 +96,94 @@ class PtCreater(object):
         parcel['pt_addr1'] = self.parsed_toml["pt_table"]["address1"]
         version_sign = 1
         try:
-            if "version" in self.parsed_toml["pt_table"] and self.parsed_toml["pt_table"]["version"]==2:
+            if "version" in self.parsed_toml["pt_table"] and self.parsed_toml["pt_table"]["version"] == 2:
                 version_sign = 2
-                parcel["version"] = 2#self.parsed_toml["pt_table"]["version"]
+                parcel["version"] = 2
         except:
             pass
-        if version_sign==1:
+        if version_sign == 1:
             for tbl_item in self.parsed_toml["pt_entry"]:
-                if tbl_item['name'].upper()  == 'FW_CPU0':
+                name = tbl_item['name'].lower()
+                if name.upper() == 'FW_CPU0':
                     parcel['fw_cpu0_addr'] = tbl_item['address0']
                     parcel['fw_cpu0_len'] = tbl_item['size0']
                     parcel['fw1_cpu0_addr'] = tbl_item['address1']
                     parcel['fw1_cpu0_len'] = tbl_item['size1']
-                if tbl_item['name'].upper()  == 'FW_GRP0':
+                    parcel['fw1_cpu0_header'] = 1
+                elif name.upper() == 'FW_GRP0':
                     parcel['fw_group0_addr'] = tbl_item['address0']
                     parcel['fw_group0_len'] = tbl_item['size0']
                     parcel['fw1_group0_addr'] = tbl_item['address1']
                     parcel['fw1_group0_len'] = tbl_item['size1']
-                if tbl_item['name'].upper()  == 'FW_GRP1':
+                    parcel['fw1_group0_header'] = 1
+                elif name.upper() == 'FW_GRP1':
                     parcel['fw_group1_addr'] = tbl_item['address0']
                     parcel['fw_group1_len'] = tbl_item['size0']
                     parcel['fw1_group1_addr'] = tbl_item['address1']
                     parcel['fw1_group1_len'] = tbl_item['size1']
-                if tbl_item['name'].lower() == 'factory':
-                    parcel['conf_addr'] = tbl_item['address0']
-                    parcel['conf_len'] = tbl_item['size0']
-                if tbl_item['name'].upper()  == 'FW':
+                    parcel['fw1_group1_header'] = 1
+                elif name.lower() == 'factory':
+                    parcel['factory_addr'] = tbl_item['address0']
+                    parcel['factory_len'] = tbl_item['size0']
+                    parcel['factory_header'] = 0
+                elif name.upper() == 'FW':
                     parcel['fw_addr'] = tbl_item['address0']
                     parcel['fw_len'] = tbl_item['size0']
                     parcel['fw1_addr'] = tbl_item['address1']
                     parcel['fw1_len'] = tbl_item['size1']
-                if tbl_item['name'].upper()  == 'D0FW':
-                    parcel['fw_d0_addr'] = tbl_item['address0']
-                    parcel['fw_d0_len'] = tbl_item['size0']
-                    parcel['fw1_d0_addr'] = tbl_item['address1']
-                    parcel['fw1_d0_len'] = tbl_item['size1']
-                if tbl_item['name'].lower() == 'imtb':
+                    parcel['fw_header'] = 1
+                elif name.upper() == 'D0FW':
+                    parcel['d0fw_addr'] = tbl_item['address0']
+                    parcel['d0fw_len'] = tbl_item['size0']
+                    parcel['d0fw1_addr'] = tbl_item['address1']
+                    parcel['d0fw1_len'] = tbl_item['size1']
+                    parcel['d0fw_header'] = 1
+                elif name.lower() == 'imtb':
                     parcel['imtb_addr'] = tbl_item['address0']
                     parcel['imtb_len'] = tbl_item['size0']
-                if tbl_item['name'].lower() == 'media':
+                    parcel['imtb_header'] = 0
+                elif name.lower() == 'media':
                     parcel['media_addr'] = tbl_item['address0']
                     parcel['media_len'] = tbl_item['size0']
-                if tbl_item['name'].lower() == 'kv':
+                    parcel['media_header'] = 0
+                elif name.lower() == 'kv':
                     parcel['kv_addr'] = tbl_item['address0']
                     parcel['kv_len'] = tbl_item['size0']
-                if tbl_item['name'].lower() == 'yocboot':
-                    parcel['fw_yocboot_addr'] = tbl_item['address0']
-                    parcel['fw_yocboot_len'] = tbl_item['size0']                
-                if tbl_item['name'].lower() == 'mfg':
+                    parcel['kv_header'] = 0
+                elif name.lower() == 'yocboot':
+                    parcel['yocboot_addr'] = tbl_item['address0']
+                    parcel['yocboot_len'] = tbl_item['size0']  
+                    parcel['yocboot_header'] = 1              
+                elif name.lower() == 'mfg':
                     parcel['mfg_addr'] = tbl_item['address0']
                     parcel['mfg_len'] = tbl_item['size0']
-                if tbl_item['name'].lower() == 'imgload':
-                    parcel['imgloader_addr'] = tbl_item['address0']
-                    parcel['imgloader_len'] = tbl_item['size0']
-                if tbl_item['name'].lower() == 'sbi':
+                    parcel['mfg_header'] = 1
+                elif name.lower() == 'imgload':
+                    parcel['imgload_addr'] = tbl_item['address0']
+                    parcel['imgload_len'] = tbl_item['size0']
+                    parcel['imgload_header'] = 1
+                elif name.lower() == 'sbi':
                     parcel['sbi_addr'] = tbl_item['address0']
                     parcel['sbi_len'] = tbl_item['size0']
-                if tbl_item['name'].lower() == 'kernel':
+                    parcel['sbi_header'] = 1
+                elif name.lower() == 'kernel':
                     parcel['kernel_addr'] = tbl_item['address0']
                     parcel['kernel_len'] = tbl_item['size0']
-                if tbl_item['name'].lower() == 'rootfs':
+                    parcel['kernel_header'] = 1
+                elif name.lower() == 'rootfs':
                     parcel['rootfs_addr'] = tbl_item['address0']
                     parcel['rootfs_len'] = tbl_item['size0']
-                if tbl_item['name'].lower() == 'dtb':
+                    parcel['rootfs_header'] = 0
+                elif name.lower() == 'dtb':
                     parcel['dtb_addr'] = tbl_item['address0']
                     parcel['dtb_len'] = tbl_item['size0']
-        elif version_sign==2:
+                    parcel['dtb_header'] = 1
+                else:
+                    parcel[name+'_addr'] = tbl_item['address0']
+                    parcel[name+'_len'] = tbl_item['size0']
+                    parcel[name+'_header'] = 0
+                name_list.append(name.lower())
+        elif version_sign == 2:
             for tbl_item in self.parsed_toml["pt_entry"]:
                 name = tbl_item['name'].lower().replace(' ','_')
                 parcel[name+'_addr'] = tbl_item['address0']
