@@ -223,6 +223,7 @@ if conf_sign:
         "0041": "FLASH LOAD ROMFS FAIL",
         "0042": "FLASH SWITCH BANK FAIL",
         "0043": "FLASH IDENTIFY FAIL",
+        "0044": "FLASH CHIPERASE CONFLICT WITH SKIP MODE",
         "0050": "IMG LOAD SHAKEHAND FAIL",
         "0051": "IMG LOAD BOOT CHECK FAIL",
         "0060": "IMG CREATE FAIL",
@@ -388,6 +389,7 @@ else:
         "0041": "BFLB FLASH LOAD ROMFS FAIL",
         "0042": "BFLB FLASH SWITCH BANK FAIL",
         "0043": "BFLB FLASH IDENTIFY FAIL",
+        "0044": "BFLB FLASH CHIPERASE CONFLICT WITH SKIP MODE",
         "0050": "BFLB IMG LOAD SHAKEHAND FAIL",
         "0051": "BFLB IMG LOAD BOOT CHECK FAIL",
         "0060": "BFLB IMG CREATE FAIL",
@@ -426,7 +428,7 @@ else:
         "0087": "KERNEL BIN NOT SET",  
         "0088": "ROOTFS BIN NOT SET", 
         "0089": "KV BIN NOT SET",  
-        "0090": "YOCBOOT BIN NOT SET",              
+        "0090": "YOCBOOT BIN NOT SET",
         "FFFF": "BFLB BURN RETRY FAIL",
     }
 
